"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpHelper = void 0;
const ihub_error_1 = require("../utils/ihub-error");
const lodash_1 = require("lodash");
class HttpHelper {
    static jsonResponse(res, code, message) {
        return res.status(code).json({ message });
    }
    static ok(res, dto, allowedFields) {
        if (dto) {
            res.type('application/json');
            return res.status(200).json(allowedFields && allowedFields.length > 0 ? lodash_1.pick(dto, allowedFields) : dto);
        }
        else {
            return res.sendStatus(200);
        }
    }
    static created(res, dto, allowedFields) {
        if (dto) {
            res.type('application/json');
            return res.status(201).json(allowedFields && allowedFields.length > 0 ? lodash_1.pick(dto, allowedFields) : dto);
        }
        else {
            return res.sendStatus(201);
        }
    }
    static clientError(res, message) {
        return HttpHelper.jsonResponse(res, 400, message ? message : 'Bad request');
    }
    static unauthorized(res, message) {
        return HttpHelper.jsonResponse(res, 401, message ? message : 'Unauthorized');
    }
    static paymentRequired(res, message) {
        return HttpHelper.jsonResponse(res, 402, message ? message : 'Payment required');
    }
    static forbidden(res, message) {
        return HttpHelper.jsonResponse(res, 403, message ? message : 'Forbidden');
    }
    static notFound(res, message) {
        return HttpHelper.jsonResponse(res, 404, message ? message : 'Not found');
    }
    static conflict(res, message) {
        return HttpHelper.jsonResponse(res, 409, message ? message : 'Conflict');
    }
    static tooMany(res, message) {
        return HttpHelper.jsonResponse(res, 429, message ? message : 'Too many requests');
    }
    static todo(res) {
        return HttpHelper.jsonResponse(res, 400, 'TODO');
    }
    static fail(res, error) {
        if (error instanceof ihub_error_1.IHubError) {
            const { httpStatus, code, message } = error;
            res.status(httpStatus || 500).json({
                code: code || 'ihub.uncaughtException',
                message,
            });
        }
        else {
            return res.status(500).json({
                message: error.toString()
            });
        }
    }
}
exports.HttpHelper = HttpHelper;
//# sourceMappingURL=httpHelper.js.map