"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PaginationHelper = void 0;
const PER_PAGE_LIMIT = 50;
class PaginationHelper {
    static createPaginationParams(req, sortableFields) {
        const { query } = req;
        const { 
        // Pagination info
        page = 1, perPage = 20, orderBy, orderDirection, } = query;
        if (orderBy && !sortableFields.includes(orderBy.toString())) {
            throw new Error(`Informed field "${orderBy}" is not sortable.`);
        }
        if (orderDirection && !['asc', 'desc'].includes(orderDirection.toString())) {
            throw new Error(`Informed field "${orderDirection}" is not valid.`);
        }
        const pageNumber = Math.max(+page, 1);
        let perPageLimitNumber = Math.max(+perPage, PER_PAGE_LIMIT);
        perPageLimitNumber = Math.min(perPageLimitNumber, PER_PAGE_LIMIT);
        const paginationParams = {
            pageNumber,
            perPage: perPageLimitNumber,
            orderBy,
            orderDirection,
            sortableFields,
        };
        return paginationParams;
    }
    static getPaginatedResponse(opt) {
        const { data, currentPage, totalItems, itemsPerPage, } = opt;
        return {
            data,
            count: data.length,
            currentPage,
            perPage: itemsPerPage,
            total: totalItems,
            pages: Math.ceil(totalItems / itemsPerPage),
        };
    }
}
exports.PaginationHelper = PaginationHelper;
//# sourceMappingURL=paginationHelper.js.map